/* Program name                                                              */

/*---------------------------------------------------------------------------*/
/* System includes                                                           */
/*---------------------------------------------------------------------------*/

	#include <proto/exec.h>
	#include <proto/dos.h>
	#include <proto/commodities.h>

	#include <clib/alib_protos.h>

/*---------------------------------------------------------------------------*/
/* Constants and macros                                                      */
/*---------------------------------------------------------------------------*/

	#define EVT_HOTKEY1 1L
	#define EVT_HOTKEY2 2L

/*---------------------------------------------------------------------------*/
/* Global variables                                                          */
/*---------------------------------------------------------------------------*/

#ifdef __amigaos4__	/* these should be declared and filled in auto.lib, but they aren't */
	struct Library *CxBase = NULL;
	struct CommoditiesIFace *ICommodities = NULL;
	struct Library *IconBase = NULL;
	struct IconIFace *IIcon = NULL;
#endif

	struct NewBroker newbroker = {
		NB_VERSION,
		"Test",
		"Test commodity",
		"Just to show how to wait for hotkeys",
		NBU_UNIQUE | NBU_NOTIFY,
		0, 0, 0, 0					/* set flags to COF_SHOW_HIDE if you have a GUI */
		};

/*---------------------------------------------------------------------------*/
/* Process hotkeys                                                           */
/*---------------------------------------------------------------------------*/

	void process_hotkeys (CxObj *broker,struct MsgPort *broker_mp)

	{
	CxMsg *msg;
	ULONG cxsig,sigs;
	BOOL cont;
	ULONG msgid,msgtype;

	cxsig = 1L << broker_mp->mp_SigBit;
	cont = TRUE;
	do	{
		sigs = Wait (cxsig | SIGBREAKF_CTRL_C);
		if (sigs & SIGBREAKF_CTRL_C)
			cont = FALSE;
		if (sigs & cxsig)
			{
			while (msg = (CxMsg *) GetMsg (broker_mp))
				{
				msgid   = CxMsgID (msg);
				msgtype = CxMsgType (msg);
				ReplyMsg ((struct Message *) msg);
				switch (msgtype)
					{
				case CXM_IEVENT:
					switch (msgid)
						{
					case EVT_HOTKEY1:
						Printf ("Hotkey 1 pressed\n");
						break;
					case EVT_HOTKEY2:
						Printf ("Hotkey 2 pressed\n");
						break;
						}
					break;
				case CXM_COMMAND:
					switch (msgid)
						{
					case CXCMD_DISABLE:
						ActivateCxObj (broker, 0L);
						Printf ("Commodity disabled\n");
						break;
					case CXCMD_ENABLE:
						ActivateCxObj (broker, 1L);
						Printf ("Commodity enabled\n");
						break;
					case CXCMD_KILL:
						Printf ("Commodity has been killed\n");
						cont = FALSE;
						break;
					case CXCMD_UNIQUE:
						Printf ("Another commodity with the same name was started\n");
						cont = FALSE;
						break;
						}
					break;
					}
				}
			}
		}
	while (cont);
	}

/*---------------------------------------------------------------------------*/
/* Main program                                                              */
/*---------------------------------------------------------------------------*/

	int main (LONG argc,CONST_STRPTR *argv)

	{
	struct MsgPort *broker_mp;
	CxObj *broker, *filter1, *filter2;
	CONST_STRPTR *ttypes;
	char *hotkey1, *hotkey2;
	CxMsg *msg;

#ifdef __amigaos4__
	if (
		(CxBase = OpenLibrary ("commodities.library",0)) &&
		(ICommodities = (struct CommoditiesIFace *) GetInterface (CxBase,"main",1,NULL)) &&
		(IconBase = OpenLibrary ("icon.library",0)) &&
		(IIcon = (struct IconIFace *) GetInterface (IconBase,"main",1,NULL))
	   )
		{
#endif
		ttypes = (CONST_STRPTR *) ArgArrayInit(argc, argv);

		if (broker_mp = CreateMsgPort())
			{
			newbroker.nb_Port = broker_mp;
			newbroker.nb_Pri  = ArgInt (ttypes, "CX_PRIORITY", 0);
			hotkey1 = ArgString (ttypes, "HOTKEY1", "rawkey control alt x");
			hotkey2 = ArgString (ttypes, "HOTKEY2", "rawkey control alt y");
			if (broker = CxBroker(&newbroker, NULL))
				{
				if (filter1 = HotKey (hotkey1, broker_mp, EVT_HOTKEY1))
					{
					AttachCxObj(broker, filter1);
					if (filter2 = HotKey (hotkey2, broker_mp, EVT_HOTKEY2))
						{
						AttachCxObj(broker, filter2);
						if (!CxObjError(filter1) && !CxObjError(filter2))
							{
							ActivateCxObj(broker, 1L);
							process_hotkeys (broker,broker_mp);
							}
						}
					}
				DeleteCxObjAll (broker);
				while(msg = (CxMsg *)GetMsg(broker_mp))
					ReplyMsg ((struct Message *)msg);
				}

			DeleteMsgPort (broker_mp);
			}

		ArgArrayDone();
#ifdef __amigaos4__
		}

	if (IIcon) DropInterface ((struct Interface *)IIcon);
	if (IconBase) CloseLibrary (IconBase);
	if (ICommodities) DropInterface ((struct Interface *)ICommodities);
	if (CxBase) CloseLibrary (CxBase);
#endif

	return (0);
	}

/*---------------------------------------------------------------------------*/
/* End of source text                                                        */
/*---------------------------------------------------------------------------*/
